pub enum Ty {
}Expand description
A PHP type.
Variants
Unknown
Type is not known / not yet inferred.
Never
The never return type (function never returns normally).
Void
The void return type.
Null
null.
Bool
bool.
Int
int.
Float
float.
Str
string.
Array
Untyped array.
Callable
callable.
Object(String)
A named object type (fully-qualified or short class/interface name).
Union(Vec<Ty>)
T1|T2|…
Intersection(Vec<Ty>)
T1&T2&…
Implementations
Sourceimpl Ty
impl Ty
Sourcepub fn class_name(&self) -> Option<&str>
pub fn class_name(&self) -> Option<&str>
If this is a single named object type, return its class name.
Sourcepub fn is_nullable(&self) -> bool
pub fn is_nullable(&self) -> bool
True if null is a valid value for this type.